Re: fix git-pack-redundant crashing sometimes
- From
Alex Riesen <raa.lkml@gmail.com>
- Date
- Nov 16, 2005, 21:11 UTC
- Message-ID
- <20051116211128.GA13975@steel.home>
- In-Reply-To
- <437A6B8A.8060905@etek.chalmers.se>
Lukas Sandström, Wed, Nov 16, 2005 00:13:14 +0100:
Show 18 quoted lines
> After giving it a quick look, I don't think it locks up. It is just horribly > slow. get_all_permutations returns (nice ASCII-art follows) > > ___n___ > \ > \ ____1____ > n! * / k!(n-k)! > /______ > k=1 > > permutations, which for your case (22 packs) adds up to 4194303. > > I'll look into an optimization so we won't have to call is_superset > for every one of them. > > OTOH, I might be wrong and it could very well be an infinite loop. > Mind running it over the night? I won't look further into this in > 20 hours or so anyway.
It doesn't lock up:
$ time git-pack-redundant --all --alt-odb .git/objects/pack/pack-3c5133604508466855453f3e609428f4bbba9131.idx .git/objects/pack/pack-3c5133604508466855453f3e609428f4bbba9131.pack ...
real 24m55.277s user 24m50.778s sys 0m0.582s
Now I shall be called "too impatient", perhaps?